==> estateplat-common-1.2.4-20200915.063902-438-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGg.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/29
 * @description 不动产公告
 */
@Table(name = "bdc_gg")
public class BdcGg implements Serializable {

    @Id
    private String ggid; //公告id
    private String wiid; //工作流id
    private String proid; //项目id
    private String ggbh; //公告编号
    private String gglx; //公告类型
    private String ggmc; //公告名称
    private String ggnr; //公告内容
    private String sqr;  //申请人
    private Date kssj;   //开始时间
    private Date jssj;   //结束时间
    private double ggqx; //公告期限
    private String cjrid; //创建人id
    private String cjrmc; //创建人名称
    private Date cjsj;    //创建时间
    private String sffb;  //是否发布（0：未发布，1已发布）
    private String clsddz; //材料送达地址
    private String ggdw; //公告单位
    private String bz;   //备注
    private String ggyj;   //公告意见
    private String zxcds;   //执行裁定书
    private String xzzxtzs;   //协助执行通知书
    private String xmly;   //项目来源
    private String zl; //坐落
    private String bdcqllx; //不动产权利类型
    private String bzxr; //被执行人
    private String cjrbmmc;//创建人部门
    private String cjrlxdh;//创建人联系电话
    private String cjrbmdz;//创建人部门地址

    public String getCjrbmmc() {
        return cjrbmmc;
    }

    public void setCjrbmmc(String cjrbmmc) {
        this.cjrbmmc = cjrbmmc;
    }

    public String getCjrlxdh() {
        return cjrlxdh;
    }

    public void setCjrlxdh(String cjrlxdh) {
        this.cjrlxdh = cjrlxdh;
    }

    public String getCjrbmdz() {
        return cjrbmdz;
    }

    public void setCjrbmdz(String cjrbmdz) {
        this.cjrbmdz = cjrbmdz;
    }

    public String getGgmc() {
        return ggmc;
    }

    public void setGgmc(String ggmc) {
        this.ggmc = ggmc;
    }

    public String getGgid() {
        return ggid;
    }

    public void setGgid(String ggid) {
        this.ggid = ggid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getGgbh() {
        return ggbh;
    }

    public void setGgbh(String ggbh) {
        this.ggbh = ggbh;
    }

    public String getGglx() {
        return gglx;
    }

    public void setGglx(String gglx) {
        this.gglx = gglx;
    }

    public String getGgnr() {
        return ggnr;
    }

    public void setGgnr(String ggnr) {
        this.ggnr = ggnr;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public Date getKssj() {
        return kssj;
    }

    public void setKssj(Date kssj) {
        this.kssj = kssj;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public double getGgqx() {
        return ggqx;
    }

    public void setGgqx(double ggqx) {
        this.ggqx = ggqx;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getSffb() {
        return sffb;
    }

    public void setSffb(String sffb) {
        this.sffb = sffb;
    }

    public String getClsddz() {
        return clsddz;
    }

    public void setClsddz(String clsddz) {
        this.clsddz = clsddz;
    }

    public String getGgdw() {
        return ggdw;
    }

    public void setGgdw(String ggdw) {
        this.ggdw = ggdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getGgyj() {
        return ggyj;
    }

    public void setGgyj(String ggyj) {
        this.ggyj = ggyj;
    }

    public String getZxcds() {
        return zxcds;
    }

    public void setZxcds(String zxcds) {
        this.zxcds = zxcds;
    }

    public String getXzzxtzs() {
        return xzzxtzs;
    }

    public void setXzzxtzs(String xzzxtzs) {
        this.xzzxtzs = xzzxtzs;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcqllx() {
        return bdcqllx;
    }

    public void setBdcqllx(String bdcqllx) {
        this.bdcqllx = bdcqllx;
    }

    public String getBzxr() {
        return bzxr;
    }

    public void setBzxr(String bzxr) {
        this.bzxr = bzxr;
    }
}

==> estateplat-common-1.2.4-20200916.121407-443-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGg.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/29
 * @description 不动产公告
 */
@Table(name = "bdc_gg")
public class BdcGg implements Serializable {

    @Id
    private String ggid; //公告id
    private String wiid; //工作流id
    private String proid; //项目id
    private String ggbh; //公告编号
    private String gglx; //公告类型
    private String ggmc; //公告名称
    private String ggnr; //公告内容
    private String sqr;  //申请人
    private Date kssj;   //开始时间
    private Date jssj;   //结束时间
    private double ggqx; //公告期限
    private String cjrid; //创建人id
    private String cjrmc; //创建人名称
    private Date cjsj;    //创建时间
    private String sffb;  //是否发布（0：未发布，1已发布）
    private String clsddz; //材料送达地址
    private String ggdw; //公告单位
    private String bz;   //备注
    private String ggyj;   //公告意见
    private String zxcds;   //执行裁定书
    private String xzzxtzs;   //协助执行通知书
    private String xmly;   //项目来源
    private String zl; //坐落
    private String bdcqllx; //不动产权利类型
    private String bzxr; //被执行人
    private String dwlxdh;//单位联系电话

    public String getDwlxdh() {
        return dwlxdh;
    }

    public void setDwlxdh(String dwlxdh) {
        this.dwlxdh = dwlxdh;
    }

    public String getGgmc() {
        return ggmc;
    }

    public void setGgmc(String ggmc) {
        this.ggmc = ggmc;
    }

    public String getGgid() {
        return ggid;
    }

    public void setGgid(String ggid) {
        this.ggid = ggid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getGgbh() {
        return ggbh;
    }

    public void setGgbh(String ggbh) {
        this.ggbh = ggbh;
    }

    public String getGglx() {
        return gglx;
    }

    public void setGglx(String gglx) {
        this.gglx = gglx;
    }

    public String getGgnr() {
        return ggnr;
    }

    public void setGgnr(String ggnr) {
        this.ggnr = ggnr;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public Date getKssj() {
        return kssj;
    }

    public void setKssj(Date kssj) {
        this.kssj = kssj;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public double getGgqx() {
        return ggqx;
    }

    public void setGgqx(double ggqx) {
        this.ggqx = ggqx;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getSffb() {
        return sffb;
    }

    public void setSffb(String sffb) {
        this.sffb = sffb;
    }

    public String getClsddz() {
        return clsddz;
    }

    public void setClsddz(String clsddz) {
        this.clsddz = clsddz;
    }

    public String getGgdw() {
        return ggdw;
    }

    public void setGgdw(String ggdw) {
        this.ggdw = ggdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getGgyj() {
        return ggyj;
    }

    public void setGgyj(String ggyj) {
        this.ggyj = ggyj;
    }

    public String getZxcds() {
        return zxcds;
    }

    public void setZxcds(String zxcds) {
        this.zxcds = zxcds;
    }

    public String getXzzxtzs() {
        return xzzxtzs;
    }

    public void setXzzxtzs(String xzzxtzs) {
        this.xzzxtzs = xzzxtzs;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcqllx() {
        return bdcqllx;
    }

    public void setBdcqllx(String bdcqllx) {
        this.bdcqllx = bdcqllx;
    }

    public String getBzxr() {
        return bzxr;
    }

    public void setBzxr(String bzxr) {
        this.bzxr = bzxr;
    }
}
